# "fix" underlinking:
%define _disable_ld_no_undefined 1

%global extraver 13

Name:           ocaml-mccs
Version:        1.1
Release:        %mkrel 11
Summary:        Multi Criteria CUDF Solver with OCaml bindings

%global libname %(echo %{name} | sed -e 's/^ocaml-//')

# Original C/C++ code is BSD, OCaml bindings are LGPL.
# Linking exception, see included COPYING file.
License:        BSD and LGPLv3+ with exceptions
Group:          Development/OCaml
URL:            https://github.com/AltGr/ocaml-mccs
# Upstream's use of a '+' instead of a '.' makes this hard to use a macro.
Source0:        https://github.com/AltGr/ocaml-mccs/archive/%{version}+%{extraver}/%{name}-%{version}-%{extraver}.tar.gz

# Hacky workaround for:
# https://lists.fedoraproject.org/archives/list/devel@lists.fedoraproject.org/thread/M2VM5DNB7HSAJIFDGT4WAIZDA5JPE5KM/
Patch1:         ocaml-mccs-1.1-c++-flags.patch

BuildRequires:  ocaml
BuildRequires:  ocaml-dune
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-cudf-devel
BuildRequires:  glpk-devel

%description
mccs (which stands for Multi Criteria CUDF Solver) is a CUDF problem
solver developed at UNS during the European MANCOOSI project.

This project contains a stripped-down version of the mccs solver,
taken from snapshot 1.1, with a binding as an OCaml library, and
building with dune.

The binding enables interoperation with binary CUDF data from the
OCaml CUDF library, and removes the native C++ parsers and printers.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
Requires:       glpk-devel

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%autosetup -n %{name}-%{version}-%{extraver} -p1

# Choose the build method that uses an installed glpk
cp -p src/glpk/dune-shared src/glpk/dune

%build
dune build %{?_smp_mflags} --display=verbose

# Relink the stublibs with Fedora LDFLAGS
cd _build/default/src
ocamlmklib -g -ldopt "%{build_ldflags}" -o mccs_stubs $(ar t libmccs_stubs.a)
cd -

%install
dune install --destdir=%{buildroot}

# We install the documentation with the doc macro
rm -fr %{buildroot}%{_prefix}/doc

%files
%license LICENCE
%doc README.md
%{_libdir}/ocaml/%{libname}
%ifarch %{ocaml_native_compiler}
%exclude %{_libdir}/ocaml/*/*.a
%exclude %{_libdir}/ocaml/*/*.cmx
%exclude %{_libdir}/ocaml/*/*.cmxa
%endif
%exclude %{_libdir}/ocaml/*/*.mli
%{_libdir}/ocaml/stublibs/*.so

%files devel
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/*/*.a
%{_libdir}/ocaml/*/*.cmx
%{_libdir}/ocaml/*/*.cmxa
%endif
%{_libdir}/ocaml/*/*.mli



%changelog
* Fri May 20 2022 pterjan <pterjan> 1.1-11.mga9
+ Revision: 1859450
- Rebuild for OCaml 4.14

* Fri Oct 15 2021 tv <tv> 1.1-10.mga9
+ Revision: 1751503
- Rebuild for ocaml 4.13.1

* Thu Mar 25 2021 tv <tv> 1.1-9.mga9
+ Revision: 1709754
- Rebuild for ocaml-4.12
- rebuild for ocaml-4.2-12

* Sun Jan 10 2021 pterjan <pterjan> 1.1-7.mga8
+ Revision: 1670773
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 1.1-6.mga8
+ Revision: 1551745
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 1.1-5.mga8
+ Revision: 1544528
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 tv <tv> 1.1-4.mga8
+ Revision: 1483157
- new sub release + rebuild for ocaml-4.10

* Thu Oct 25 2018 daviddavid <daviddavid> 1.1-3.mga7
+ Revision: 1325164
- rebuild for new ocaml 4.07.1

* Sun Sep 23 2018 umeabot <umeabot> 1.1-2.mga7
+ Revision: 1299896
- Mageia 7 Mass Rebuild

* Tue Aug 21 2018 daviddavid <daviddavid> 1.1-1.mga7
+ Revision: 1253295
- initial package ocaml-mccs

